# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from nedo_vision_training.protos import TrainingAgentService_pb2 as nedo__vision__training_dot_protos_dot_TrainingAgentService__pb2

GRPC_GENERATED_VERSION = '1.73.1'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + f' but the generated code in nedo_vision_training/protos/TrainingAgentService_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class TrainingAgentServiceStub(object):
    """Define the TrainingAgentService
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.SendSystemUsage = channel.unary_unary(
                '/Sindika.AspNet.App005.Services.TrainingAgentService/SendSystemUsage',
                request_serializer=nedo__vision__training_dot_protos_dot_TrainingAgentService__pb2.TrainingAgentSystemUsageRequest.SerializeToString,
                response_deserializer=nedo__vision__training_dot_protos_dot_TrainingAgentService__pb2.TrainingAgentSystemUsageResponse.FromString,
                _registered_method=True)
        self.UpdateStatus = channel.unary_unary(
                '/Sindika.AspNet.App005.Services.TrainingAgentService/UpdateStatus',
                request_serializer=nedo__vision__training_dot_protos_dot_TrainingAgentService__pb2.UpdateTrainingAgentStatusRequest.SerializeToString,
                response_deserializer=nedo__vision__training_dot_protos_dot_TrainingAgentService__pb2.UpdateTrainingAgentStatusResponse.FromString,
                _registered_method=True)
        self.GetConnectionInfo = channel.unary_unary(
                '/Sindika.AspNet.App005.Services.TrainingAgentService/GetConnectionInfo',
                request_serializer=nedo__vision__training_dot_protos_dot_TrainingAgentService__pb2.GetConnectionInfoRequest.SerializeToString,
                response_deserializer=nedo__vision__training_dot_protos_dot_TrainingAgentService__pb2.GetConnectionInfoResponse.FromString,
                _registered_method=True)


class TrainingAgentServiceServicer(object):
    """Define the TrainingAgentService
    """

    def SendSystemUsage(self, request, context):
        """System Usage Service
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateStatus(self, request, context):
        """Update Status Service
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetConnectionInfo(self, request, context):
        """Connection Info Service
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_TrainingAgentServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'SendSystemUsage': grpc.unary_unary_rpc_method_handler(
                    servicer.SendSystemUsage,
                    request_deserializer=nedo__vision__training_dot_protos_dot_TrainingAgentService__pb2.TrainingAgentSystemUsageRequest.FromString,
                    response_serializer=nedo__vision__training_dot_protos_dot_TrainingAgentService__pb2.TrainingAgentSystemUsageResponse.SerializeToString,
            ),
            'UpdateStatus': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateStatus,
                    request_deserializer=nedo__vision__training_dot_protos_dot_TrainingAgentService__pb2.UpdateTrainingAgentStatusRequest.FromString,
                    response_serializer=nedo__vision__training_dot_protos_dot_TrainingAgentService__pb2.UpdateTrainingAgentStatusResponse.SerializeToString,
            ),
            'GetConnectionInfo': grpc.unary_unary_rpc_method_handler(
                    servicer.GetConnectionInfo,
                    request_deserializer=nedo__vision__training_dot_protos_dot_TrainingAgentService__pb2.GetConnectionInfoRequest.FromString,
                    response_serializer=nedo__vision__training_dot_protos_dot_TrainingAgentService__pb2.GetConnectionInfoResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'Sindika.AspNet.App005.Services.TrainingAgentService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('Sindika.AspNet.App005.Services.TrainingAgentService', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class TrainingAgentService(object):
    """Define the TrainingAgentService
    """

    @staticmethod
    def SendSystemUsage(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/Sindika.AspNet.App005.Services.TrainingAgentService/SendSystemUsage',
            nedo__vision__training_dot_protos_dot_TrainingAgentService__pb2.TrainingAgentSystemUsageRequest.SerializeToString,
            nedo__vision__training_dot_protos_dot_TrainingAgentService__pb2.TrainingAgentSystemUsageResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def UpdateStatus(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/Sindika.AspNet.App005.Services.TrainingAgentService/UpdateStatus',
            nedo__vision__training_dot_protos_dot_TrainingAgentService__pb2.UpdateTrainingAgentStatusRequest.SerializeToString,
            nedo__vision__training_dot_protos_dot_TrainingAgentService__pb2.UpdateTrainingAgentStatusResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetConnectionInfo(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/Sindika.AspNet.App005.Services.TrainingAgentService/GetConnectionInfo',
            nedo__vision__training_dot_protos_dot_TrainingAgentService__pb2.GetConnectionInfoRequest.SerializeToString,
            nedo__vision__training_dot_protos_dot_TrainingAgentService__pb2.GetConnectionInfoResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)
